==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate.md <==
# AwsIoTOverAirUpdate


```text
aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate
```

```text
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')
```



| Illustration | AwsIoTOverAirUpdate | AwsIoTOverAirUpdateCard | AwsIoTOverAirUpdateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate.png) | ![illustration for AwsIoTOverAirUpdate](../../../aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate.Local.png) | ![illustration for AwsIoTOverAirUpdateCard](../../../aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdateCard.Local.png) | ![illustration for AwsIoTOverAirUpdateGroup](../../../aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdateGroup.Local.png) |




## AwsIoTOverAirUpdate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTOverAirUpdate
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')

' renders the element
AwsIoTOverAirUpdate('AwsIoTOverAirUpdate', 'Aws Io T Over Air Update', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTOverAirUpdate
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')

' renders the element
AwsIoTOverAirUpdate('AwsIoTOverAirUpdate', 'Aws Io T Over Air Update', 'an optional tech label')
@enduml
```

## AwsIoTOverAirUpdateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTOverAirUpdateCard
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')

' renders the element
AwsIoTOverAirUpdateCard('AwsIoTOverAirUpdateCard', 'Aws Io T Over Air Update Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTOverAirUpdateCard
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')

' renders the element
AwsIoTOverAirUpdateCard('AwsIoTOverAirUpdateCard', 'Aws Io T Over Air Update Card', 'an optional description')
@enduml
```

## AwsIoTOverAirUpdateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTOverAirUpdateGroup
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')

' renders the element
AwsIoTOverAirUpdateGroup('AwsIoTOverAirUpdateGroup', 'Aws Io T Over Air Update Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTOverAirUpdateGroup
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')

' renders the element
AwsIoTOverAirUpdateGroup('AwsIoTOverAirUpdateGroup', 'Aws Io T Over Air Update Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate.md <==
# AwsIoTOverAirUpdate


```text
aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate
```

```text
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')
```



| Illustration | AwsIoTOverAirUpdate | AwsIoTOverAirUpdateCard | AwsIoTOverAirUpdateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate.png) | ![illustration for AwsIoTOverAirUpdate](../../../aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate.Local.png) | ![illustration for AwsIoTOverAirUpdateCard](../../../aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdateCard.Local.png) | ![illustration for AwsIoTOverAirUpdateGroup](../../../aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdateGroup.Local.png) |




## AwsIoTOverAirUpdate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTOverAirUpdate
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')

' renders the element
AwsIoTOverAirUpdate('AwsIoTOverAirUpdate', 'Aws Io T Over Air Update', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTOverAirUpdate
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')

' renders the element
AwsIoTOverAirUpdate('AwsIoTOverAirUpdate', 'Aws Io T Over Air Update', 'an optional tech label')
@enduml
```

## AwsIoTOverAirUpdateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTOverAirUpdateCard
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')

' renders the element
AwsIoTOverAirUpdateCard('AwsIoTOverAirUpdateCard', 'Aws Io T Over Air Update Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTOverAirUpdateCard
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')

' renders the element
AwsIoTOverAirUpdateCard('AwsIoTOverAirUpdateCard', 'Aws Io T Over Air Update Card', 'an optional description')
@enduml
```

## AwsIoTOverAirUpdateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTOverAirUpdateGroup
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')

' renders the element
AwsIoTOverAirUpdateGroup('AwsIoTOverAirUpdateGroup', 'Aws Io T Over Air Update Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTOverAirUpdateGroup
include('aws-q3-2021/Resource/LoT/AwsIoTOverAirUpdate')

' renders the element
AwsIoTOverAirUpdateGroup('AwsIoTOverAirUpdateGroup', 'Aws Io T Over Air Update Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
